@@ -85,6 +85,50 @@ gpm_control_error_quark (void)
 	return quark;
 }
 
+/**
+ * gpm_manager_systemd_shutdown:
+ *
+ * Shutdown the system using systemd-logind.
+ *
+ * Return value: fd, -1 on error
+ **/
+static gboolean
+gpm_control_systemd_shutdown (void) {
+	GError *error = NULL;
+	GDBusProxy *proxy;
+
+	egg_debug ("Requesting systemd to shutdown");
+	proxy = g_dbus_proxy_new_for_bus_sync (G_BUS_TYPE_SYSTEM,
+					       G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES,
+					       NULL,
+					       "org.freedesktop.login1",
+					       "/org/freedesktop/login1",
+					       "org.freedesktop.login1.Manager",
+					       NULL,
+					       &error );
+	//append all our arguments
+	if (proxy == NULL) {
+		egg_error("Error connecting to dbus - %s", error->message);
+		g_error_free (error);
+		return FALSE;
+	}
+
+	g_dbus_proxy_call_sync (proxy, "PowerOff",
+				g_variant_new( "(b)", FALSE),
+				G_DBUS_CALL_FLAGS_NONE,
+				-1,
+				NULL,
+				&error
+				);
+	if (error != NULL) {
+		egg_error ("Error in dbus - %s", error->message);
+		g_error_free (error);
+		return FALSE;
+	}
+
+	return TRUE;
+}
+
 /**
  * gpm_control_shutdown:
  * @control: This class instance
@@ -96,9 +140,14 @@ gpm_control_shutdown (GpmControl *control, GError **error)
 {
 	gboolean ret;
 	EggConsoleKit *console;
-	console = egg_console_kit_new ();
-	ret = egg_console_kit_stop (console, error);
-	g_object_unref (console);
+
+	if (LOGIND_RUNNING()) {
+		ret = gpm_control_systemd_shutdown ();
+	} else {
+		console = egg_console_kit_new ();
+		ret = egg_console_kit_stop (console, error);
+		g_object_unref (console);
+	}
 	return ret;
 }
 
@@ -166,23 +215,22 @@ gpm_control_suspend (GpmControl *control, GError **error)
 	gboolean lock_mate_keyring;
 	MateKeyringResult keyres;
 #endif /* WITH_KEYRING */
-#ifdef WITH_SYSTEMD_SLEEP
+
 	GError *dbus_error = NULL;
-	DBusGProxy *proxy;
-	GVariant *res;
-#endif
+	GDBusProxy *proxy;
 
 	screensaver = gpm_screensaver_new ();
-#ifndef WITH_SYSTEMD_SLEEP
-	g_object_get (control->priv->client,
-		      "can-suspend", &allowed,
-		      NULL);
-	if (!allowed) {
-		egg_debug ("cannot suspend as not allowed from policy");
-		g_set_error_literal (error, GPM_CONTROL_ERROR, GPM_CONTROL_ERROR_GENERAL, "Cannot suspend");
-		goto out;
+
+	if (LOGIND_RUNNING()) {
+		g_object_get (control->priv->client,
+			      "can-suspend", &allowed,
+			      NULL);
+		if (!allowed) {
+			egg_debug ("cannot suspend as not allowed from policy");
+			g_set_error_literal (error, GPM_CONTROL_ERROR, GPM_CONTROL_ERROR_GENERAL, "Cannot suspend");
+			goto out;
+		}
 	}
-#endif
 
 #ifdef WITH_KEYRING
 	/* we should perhaps lock keyrings when sleeping #375681 */
@@ -208,41 +256,41 @@ gpm_control_suspend (GpmControl *control, GError **error)
 	egg_debug ("emitting sleep");
 	g_signal_emit (control, signals [SLEEP], 0, GPM_CONTROL_ACTION_SUSPEND);
 
-#ifdef WITH_SYSTEMD_SLEEP
-	/* sleep via logind */
-	proxy = g_dbus_proxy_new_for_bus_sync (G_BUS_TYPE_SYSTEM,
-			G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES,
-			NULL,
-			"org.freedesktop.login1",
-			"/org/freedesktop/login1",
-			"org.freedesktop.login1.Manager",
-			NULL,
-			&dbus_error );
-    if (proxy == NULL) {
-        egg_error("Error connecting to dbus - %s", dbus_error->message);
-        fprintf(stderr,"Error connecting to dbus - %s", dbus_error->message);
-        g_error_free (dbus_error);
-        return -1;
-    }
-    g_dbus_proxy_call_sync (proxy, "Suspend", 
-                            g_variant_new( "(b)",FALSE),
-                            G_DBUS_CALL_FLAGS_NONE,
-                            -1,
-                            NULL,
-                            &dbus_error
-                            );
-    if (dbus_error != NULL ) {
-	    egg_debug ("Error in dbus - %s", dbus_error->message);
-	    g_error_free (dbus_error);
-	    ret = TRUE;
-    }
-    else {
-	    ret = TRUE;
-    }
-    g_object_unref(proxy);
-#else
-	ret = up_client_suspend_sync (control->priv->client, NULL, error);
-#endif
+	if (LOGIND_RUNNING()) {
+		/* sleep via logind */
+		proxy = g_dbus_proxy_new_for_bus_sync (G_BUS_TYPE_SYSTEM,
+						       G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES,
+						       NULL,
+						       "org.freedesktop.login1",
+						       "/org/freedesktop/login1",
+						       "org.freedesktop.login1.Manager",
+						       NULL,
+						       &dbus_error );
+		if (proxy == NULL) {
+			egg_error("Error connecting to dbus - %s", dbus_error->message);
+			g_error_free (dbus_error);
+			return -1;
+		}
+		g_dbus_proxy_call_sync (proxy, "Suspend", 
+					g_variant_new( "(b)",FALSE),
+					G_DBUS_CALL_FLAGS_NONE,
+					-1,
+					NULL,
+					&dbus_error
+					);
+		if (dbus_error != NULL ) {
+			egg_debug ("Error in dbus - %s", dbus_error->message);
+			g_error_free (dbus_error);
+			ret = TRUE;
+		}
+		else {
+			ret = TRUE;
+		}
+		g_object_unref(proxy);
+	}
+	else {
+		ret = up_client_suspend_sync (control->priv->client, NULL, error);
+	}
 
 	egg_debug ("emitting resume");
 	g_signal_emit (control, signals [RESUME], 0, GPM_CONTROL_ACTION_SUSPEND);
@@ -279,23 +327,21 @@ gpm_control_hibernate (GpmControl *control, GError **error)
 	MateKeyringResult keyres;
 #endif /* WITH_KEYRING */
 
-#ifdef WITH_SYSTEMD_SLEEP
 	GError *dbus_error = NULL;
-	DBusGProxy *proxy;
-#endif
+	GDBusProxy *proxy;
 
 	screensaver = gpm_screensaver_new ();
 
-#ifndef WITH_SYSTEMD_SLEEP
-	g_object_get (control->priv->client,
-		      "can-hibernate", &allowed,
-		      NULL);
-	if (!allowed) {
-		egg_debug ("cannot hibernate as not allowed from policy");
-		g_set_error_literal (error, GPM_CONTROL_ERROR, GPM_CONTROL_ERROR_GENERAL, "Cannot hibernate");
-		goto out;
+	if (!LOGIND_RUNNING()) {
+		g_object_get (control->priv->client,
+			      "can-hibernate", &allowed,
+			      NULL);
+		if (!allowed) {
+			egg_debug ("cannot hibernate as not allowed from policy");
+			g_set_error_literal (error, GPM_CONTROL_ERROR, GPM_CONTROL_ERROR_GENERAL, "Cannot hibernate");
+			goto out;
+		}
 	}
-#endif
 
 #ifdef WITH_KEYRING
 	/* we should perhaps lock keyrings when sleeping #375681 */
@@ -321,41 +367,41 @@ gpm_control_hibernate (GpmControl *control, GError **error)
 	egg_debug ("emitting sleep");
 	g_signal_emit (control, signals [SLEEP], 0, GPM_CONTROL_ACTION_HIBERNATE);
 
-#ifdef WITH_SYSTEMD_SLEEP
-	/* sleep via logind */
-	fprintf(stderr,"logind suspend\n");
-	proxy = g_dbus_proxy_new_for_bus_sync (G_BUS_TYPE_SYSTEM,
-			G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES,
-			NULL,
-			"org.freedesktop.login1",
-			"/org/freedesktop/login1",
-			"org.freedesktop.login1.Manager",
-			NULL,
-			&dbus_error );
-    if (proxy == NULL) {
-        egg_error("Error connecting to dbus - %s", dbus_error->message);
-        fprintf(stderr,"Error connecting to dbus - %s", dbus_error->message);
-        g_error_free (dbus_error);
-        return -1;
-    }
-    g_dbus_proxy_call_sync (proxy, "Hibernate", 
-                            g_variant_new( "(b)",FALSE),
-                            G_DBUS_CALL_FLAGS_NONE,
-                            -1,
-                            NULL,
-                            &dbus_error
-                            );
-    if (dbus_error != NULL ) {
-	    egg_debug ("Error in dbus - %s", dbus_error->message);
-	    g_error_free (dbus_error);
-	    ret = TRUE;
-    }
-    else {
-	    ret = TRUE;
-    }
-#else
-	ret = up_client_hibernate_sync (control->priv->client, NULL, error);
-#endif
+	if (LOGIND_RUNNING()) {
+		/* sleep via logind */
+		proxy = g_dbus_proxy_new_for_bus_sync (G_BUS_TYPE_SYSTEM,
+						       G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES,
+						       NULL,
+						       "org.freedesktop.login1",
+						       "/org/freedesktop/login1",
+						       "org.freedesktop.login1.Manager",
+						       NULL,
+						       &dbus_error );
+		if (proxy == NULL) {
+			egg_error("Error connecting to dbus - %s", dbus_error->message);
+			g_error_free (dbus_error);
+			return -1;
+		}
+		g_dbus_proxy_call_sync (proxy, "Hibernate", 
+					g_variant_new( "(b)",FALSE),
+					G_DBUS_CALL_FLAGS_NONE,
+					-1,
+					NULL,
+					&dbus_error
+					);
+		if (dbus_error != NULL ) {
+			egg_debug ("Error in dbus - %s", dbus_error->message);
+			g_error_free (dbus_error);
+			ret = TRUE;
+		}
+		else {
+			ret = TRUE;
+		}
+	}
+	else {
+		ret = up_client_hibernate_sync (control->priv->client, NULL, error);
+	}
+
 	egg_debug ("emitting resume");
 	g_signal_emit (control, signals [RESUME], 0, GPM_CONTROL_ACTION_HIBERNATE);
 
